@@ -57,7 +57,7 @@ def _display_mimetype(mimetype, objs, raw=False, metadata=None):
     ----------
     mimetype : str
         The mimetype to be published (e.g. 'image/png')
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw text data to
         display.
     raw : bool
@@ -139,7 +139,7 @@ def display(*objs, include=None, exclude=None, metadata=None, transient=None, di
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display.
     raw : bool, optional
         Are the objects to be displayed already mimetype-keyed dicts of raw display data,
@@ -163,6 +163,9 @@ def display(*objs, include=None, exclude=None, metadata=None, transient=None, di
         Set an id for the display.
         This id can be used for updating this display area later via update_display.
         If given as `True`, generate a new `display_id`
+    clear : bool, optional
+        Should the output area be cleared before displaying anything? If True,
+        this will wait for additional output before clearing. [default: False]
     kwargs: additional keyword-args, optional
         Additional keyword-arguments are passed through to the display publisher.
 
@@ -281,8 +284,9 @@ def display(*objs, include=None, exclude=None, metadata=None, transient=None, di
         # Directly print objects.
         print(*objs)
         return
-    
-    raw = kwargs.pop('raw', False)
+
+    raw = kwargs.pop("raw", False)
+    clear = kwargs.pop("clear", False)
     if transient is None:
         transient = {}
     if metadata is None:
@@ -296,9 +300,19 @@ def display(*objs, include=None, exclude=None, metadata=None, transient=None, di
     if transient:
         kwargs['transient'] = transient
 
+    if not objs and display_id:
+        # if given no objects, but still a request for a display_id,
+        # we assume the user wants to insert an empty output that
+        # can be updated later
+        objs = [{}]
+        raw = True
+
     if not raw:
         format = InteractiveShell.instance().display_formatter.format
 
+    if clear:
+        clear_output(wait=True)
+
     for obj in objs:
         if raw:
             publish_display_data(data=obj, metadata=metadata, **kwargs)
@@ -391,7 +405,7 @@ def display_pretty(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw text data to
         display.
     raw : bool
@@ -411,7 +425,7 @@ def display_html(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw HTML data to
         display.
     raw : bool
@@ -428,7 +442,7 @@ def display_markdown(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw markdown data to
         display.
     raw : bool
@@ -446,7 +460,7 @@ def display_svg(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw svg data to
         display.
     raw : bool
@@ -463,7 +477,7 @@ def display_png(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw png data to
         display.
     raw : bool
@@ -480,7 +494,7 @@ def display_jpeg(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw JPEG data to
         display.
     raw : bool
@@ -497,7 +511,7 @@ def display_latex(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw latex data to
         display.
     raw : bool
@@ -516,7 +530,7 @@ def display_json(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw json data to
         display.
     raw : bool
@@ -533,7 +547,7 @@ def display_javascript(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw javascript data to
         display.
     raw : bool
@@ -550,7 +564,7 @@ def display_pdf(*objs, **kwargs):
 
     Parameters
     ----------
-    objs : tuple of objects
+    *objs : object
         The Python objects to display, or if raw=True raw javascript data to
         display.
     raw : bool
@@ -608,9 +622,12 @@ class DisplayObject(object):
                 filename = data
                 data = None
 
-        self.data = data
         self.url = url
         self.filename = filename
+        # because of @data.setter methods in
+        # subclasses ensure url and filename are set
+        # before assigning to self.data
+        self.data = data
 
         if metadata is not None:
             self.metadata = metadata
@@ -645,23 +662,36 @@ class DisplayObject(object):
             with open(self.filename, self._read_flags) as f:
                 self.data = f.read()
         elif self.url is not None:
-            try:
-                # Deferred import
-                from urllib.request import urlopen
-                response = urlopen(self.url)
-                self.data = response.read()
-                # extract encoding from header, if there is one:
-                encoding = None
+            # Deferred import
+            from urllib.request import urlopen
+            response = urlopen(self.url)
+            data = response.read()
+            # extract encoding from header, if there is one:
+            encoding = None
+            if 'content-type' in response.headers:
                 for sub in response.headers['content-type'].split(';'):
                     sub = sub.strip()
                     if sub.startswith('charset'):
                         encoding = sub.split('=')[-1].strip()
                         break
-                # decode data, if an encoding was specified
-                if encoding:
-                    self.data = self.data.decode(encoding, 'replace')
-            except:
-                self.data = None
+            if 'content-encoding' in response.headers:
+                # TODO: do deflate?
+                if 'gzip' in response.headers['content-encoding']:
+                    import gzip
+                    from io import BytesIO
+                    with gzip.open(BytesIO(data), 'rt', encoding=encoding) as fp:
+                        encoding = None
+                        data = fp.read()
+
+            # decode data, if an encoding was specified
+            # We only touch self.data once since
+            # subclasses such as SVG have @data.setter methods
+            # that transform self.data into ... well svg.
+            if encoding:
+                self.data = data.decode(encoding, 'replace')
+            else:
+                self.data = data
+
 
 class TextDisplayObject(DisplayObject):
     """Validate that display data is text"""
@@ -729,6 +759,11 @@ class Latex(TextDisplayObject):
 
 
 class SVG(DisplayObject):
+    """Embed an SVG into the display.
+
+    Note if you just want to view a svg image via a URL use `:class:Image` with
+    a url=URL keyword argument.
+    """
 
     _read_flags = 'rb'
     # wrap data in a property, which extracts the <svg> tag, discarding
@@ -872,7 +907,7 @@ class JSON(DisplayObject):
             data = str(data)
 
         if isinstance(data, str):
-            if getattr(self, 'filename', None) is None:
+            if self.filename is None and self.url is None:
                 warnings.warn("JSON expects JSONable dict or list, not JSON strings")
             data = json.loads(data)
         self._data = data
@@ -1301,7 +1336,7 @@ class Image(DisplayObject):
 class Video(DisplayObject):
 
     def __init__(self, data=None, url=None, filename=None, embed=False,
-                 mimetype=None, width=None, height=None):
+                 mimetype=None, width=None, height=None, html_attributes="controls"):
         """Create a video object given raw data or an URL.
 
         When this object is returned by an input cell or passed to the
@@ -1312,19 +1347,19 @@ class Video(DisplayObject):
         ----------
         data : unicode, str or bytes
             The raw video data or a URL or filename to load the data from.
-            Raw data will require passing `embed=True`.
+            Raw data will require passing ``embed=True``.
         url : unicode
-            A URL for the video. If you specify `url=`,
+            A URL for the video. If you specify ``url=``,
             the image data will not be embedded.
         filename : unicode
             Path to a local file containing the video.
-            Will be interpreted as a local URL unless `embed=True`.
+            Will be interpreted as a local URL unless ``embed=True``.
         embed : bool
             Should the video be embedded using a data URI (True) or be
             loaded using a <video> tag (False).
 
             Since videos are large, embedding them should be avoided, if possible.
-            You must confirm embedding as your intention by passing `embed=True`.
+            You must confirm embedding as your intention by passing ``embed=True``.
 
             Local files can be displayed with URLs without embedding the content, via::
 
@@ -1339,14 +1374,22 @@ class Video(DisplayObject):
         height : int
             Height in pixels to which to constrain the video in html.
             If not supplied, defaults to the height of the video.
+        html_attributes : str
+            Attributes for the HTML ``<video>`` block.
+            Default: ``"controls"`` to get video controls.
+            Other examples: ``"controls muted"`` for muted video with controls,
+            ``"loop autoplay"`` for looping autoplaying video without controls.
 
         Examples
         --------
 
-        Video('https://archive.org/download/Sita_Sings_the_Blues/Sita_Sings_the_Blues_small.mp4')
-        Video('path/to/video.mp4')
-        Video('path/to/video.mp4', embed=True)
-        Video(b'raw-videodata', embed=True)
+        ::
+
+            Video('https://archive.org/download/Sita_Sings_the_Blues/Sita_Sings_the_Blues_small.mp4')
+            Video('path/to/video.mp4')
+            Video('path/to/video.mp4', embed=True)
+            Video('path/to/video.mp4', embed=True, html_attributes="controls muted autoplay")
+            Video(b'raw-videodata', embed=True)
         """
         if isinstance(data, (Path, PurePath)):
             data = str(data)
@@ -1370,6 +1413,7 @@ class Video(DisplayObject):
         self.embed = embed
         self.width = width
         self.height = height
+        self.html_attributes = html_attributes
         super(Video, self).__init__(data=data, url=url, filename=filename)
 
     def _repr_html_(self):
@@ -1383,9 +1427,9 @@ class Video(DisplayObject):
         # notebook output.
         if not self.embed:
             url = self.url if self.url is not None else self.filename
-            output = """<video src="{0}" controls {1} {2}>
+            output = """<video src="{0}" {1} {2} {3}>
       Your browser does not support the <code>video</code> element.
-    </video>""".format(url, width, height)
+    </video>""".format(url, self.html_attributes, width, height)
             return output
 
         # Embedded videos are base64-encoded.
@@ -1404,10 +1448,10 @@ class Video(DisplayObject):
         else:
             b64_video = b2a_base64(video).decode('ascii').rstrip()
 
-        output = """<video controls {0} {1}>
- <source src="data:{2};base64,{3}" type="{2}">
+        output = """<video {0} {1} {2}>
+ <source src="data:{3};base64,{4}" type="{3}">
  Your browser does not support the video tag.
- </video>""".format(width, height, mimetype, b64_video)
+ </video>""".format(self.html_attributes, width, height, mimetype, b64_video)
         return output
 
     def reload(self):
@@ -1434,7 +1478,12 @@ def clear_output(wait=False):
 
 @skip_doctest
 def set_matplotlib_formats(*formats, **kwargs):
-    """Select figure formats for the inline backend. Optionally pass quality for JPEG.
+    """
+    .. deprecated:: 7.23
+
+       use `matplotlib_inline.backend_inline.set_matplotlib_formats()`
+
+    Select figure formats for the inline backend. Optionally pass quality for JPEG.
 
     For example, this enables PNG and JPEG output with a JPEG quality of 90%::
 
@@ -1452,20 +1501,28 @@ def set_matplotlib_formats(*formats, **kwargs):
     **kwargs :
         Keyword args will be relayed to ``figure.canvas.print_figure``.
     """
-    from IPython.core.interactiveshell import InteractiveShell
-    from IPython.core.pylabtools import select_figure_formats
-    # build kwargs, starting with InlineBackend config
-    kw = {}
-    from ipykernel.pylab.config import InlineBackend
-    cfg = InlineBackend.instance()
-    kw.update(cfg.print_figure_kwargs)
-    kw.update(**kwargs)
-    shell = InteractiveShell.instance()
-    select_figure_formats(shell, formats, **kw)
+    warnings.warn(
+        "`set_matplotlib_formats` is deprecated since IPython 7.23, directly "
+        "use `matplotlib_inline.backend_inline.set_matplotlib_formats()`",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    from matplotlib_inline.backend_inline import (
+        set_matplotlib_formats as set_matplotlib_formats_orig,
+    )
+
+    set_matplotlib_formats_orig(*formats, **kwargs)
 
 @skip_doctest
 def set_matplotlib_close(close=True):
-    """Set whether the inline backend closes all figures automatically or not.
+    """
+    .. deprecated:: 7.23
+
+        use `matplotlib_inline.backend_inline.set_matplotlib_close()`
+
+
+    Set whether the inline backend closes all figures automatically or not.
 
     By default, the inline backend used in the IPython Notebook will close all
     matplotlib figures automatically after each cell is run. This means that
@@ -1485,6 +1542,15 @@ def set_matplotlib_close(close=True):
         Should all matplotlib figures be automatically closed after each cell is
         run?
     """
-    from ipykernel.pylab.config import InlineBackend
-    cfg = InlineBackend.instance()
-    cfg.close_figures = close
+    warnings.warn(
+        "`set_matplotlib_close` is deprecated since IPython 7.23, directly "
+        "use `matplotlib_inline.backend_inline.set_matplotlib_close()`",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    from matplotlib_inline.backend_inline import (
+        set_matplotlib_close as set_matplotlib_close_orig,
+    )
+
+    set_matplotlib_close_orig(close)
